@@ -147,7 +147,7 @@ BEGIN
    'WState'  =>  'int',
 );
 
-$headerSubdirectories = "kio/|phonon/ui/|kmediaplayer/|dnssd/|solid/|solid/ifaces/|phonon/|sonnet/|kdevelop/|kinterfacedesigner/|kontact/|kate/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|kdeprint/|kdesu/|knewstuff/|dbus-1.0/dbus/|plasma/|plasma/widgets/|kresources/"
+$headerSubdirectories = "kio/|phonon/ui/|kmediaplayer/|dnssd/|solid/|solid/ifaces/|phonon/|sonnet/|kdevelop/|kinterfacedesigner/|kontact/|kate/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|kdeprint/|kdesu/|knewstuff/|dbus-1.0/dbus/|plasma/|plasma/widgets/|kresources|soprano/"
 
 }
 
@@ -290,7 +290,6 @@ sub preParseClass
 			|| $className eq 'KIO::NetRC'
 			|| $className eq 'KMimeTypeChooserDialog'
 			|| $className eq 'KParts::ComponentFactory'
-			|| $className eq 'KParts::MainWindow'
 			|| $className eq 'KParts::Plugin::PluginInfo'
 			|| $className eq 'KProtocolInfo::ExtraField'
 			|| $className eq 'KServiceTypeProfile'
@@ -443,11 +442,16 @@ sub preParseClass
 			|| $name eq 'qWarning' 
 			|| $name eq 'qCritical' 
 			|| $name eq 'qDebug' 
+			|| $name eq 'qFindString' 
+			|| $name eq 'qFindStringBoyerMoore' 
             # qHash() gives problems with building the Qwt lib
 			|| $name eq 'qHash' 
+			|| ($#{$m->{ParamList}} > -1 && $m->{ParamList}[0]->{ArgType} =~ /Private/)
+			|| ($classNode->{astNodeName} eq 'QGraphicsLinearLayout' and $name eq 'dump')
 			|| ($classNode->{astNodeName} eq 'TextEvent' and $name eq 'data')
 			|| ($classNode->{astNodeName} eq 'KConfigGroup' and $name eq 'groupImpl')
 			|| ($classNode->{astNodeName} eq 'KConfigGroup' and $name eq 'setReadDefaults')
+			|| ($classNode->{astNodeName} eq 'KConfigGroup' and $name eq 'KConfigGroup' && $#{$m->{ParamList}} == 1 && $m->{ParamList}[0]->{ArgType} =~ /const KConfigBase/)
 			|| ($name eq 'operator<<' and $m->{ParamList}[0]->{ArgType} =~ /QDebug/ )
 			|| ($name eq 'operator<<' and $m->{ParamList}[0]->{ArgType} =~ /QDataStream/ and $m->{ParamList}[1]->{ArgType} =~ /KDateTime::Spec/ )
 			|| ($name eq 'operator>>' and $m->{ParamList}[0]->{ArgType} =~ /QDataStream/ and $m->{ParamList}[1]->{ArgType} =~ /KDateTime::Spec/ )
@@ -458,6 +462,7 @@ sub preParseClass
 			|| ($classNode->{astNodeName} eq 'KIO' and $name eq 'buildHTMLErrorString')
 			|| ($classNode->{astNodeName} eq 'KJob' and $name eq 'description')
 			|| ($classNode->{astNodeName} eq 'KJob' and $name eq 'KJob')
+			|| ($className eq 'KParts::MainWindow' and $name eq 'MainWindow' && $#{$m->{ParamList}} == 2 && $m->{ParamList}[2]->{ArgType} =~ /Qt::WindowFlags/)
 			|| ($classNode->{astNodeName} eq 'KShortcutsEditor' and $name eq 'checkGlobalShortcutsConflict')
 			|| ($classNode->{astNodeName} eq 'KShortcutsEditor' and $name eq 'checkStandardShortcutsConflict')
 			|| ($classNode->{astNodeName} eq 'KStandardShortcut' and $name eq 'insert')
@@ -492,7 +497,6 @@ sub preParseClass
 			}
 		}
 
-		
 	    my $argId = 0;
 	    my $firstDefaultParam;
 	    foreach my $arg ( @{$m->{ParamList}} ) {
@@ -519,6 +523,12 @@ sub preParseClass
 		}
 	    }
 	    $m->AddProp( "FirstDefaultParam", $firstDefaultParam );
+
+		if ($className eq 'KParts::MainWindow' and $name eq 'MainWindow' && $#{$m->{ParamList}} == 1) {
+			$m->{ParamList}[1]->{DefaultValue} = undef;
+			$m->{FirstDefaultParam} = undef;
+        }
+		
 	    $m->{ReturnType} = kalyptusDataDict::resolveType($m->{ReturnType}, $classNode, $rootnode) if ($m->{ReturnType});
 	    registerType( $m->{ReturnType} );
 	}
@@ -544,6 +554,7 @@ sub preParseClass
  	} elsif( $m->{NodeType} eq 'var' ) {
 		if (	($classNode->{astNodeName} eq 'QUuid' and $name eq 'data4')
 				|| ($name eq 'd')
+				|| ($classNode->{astNodeName} eq 'Tab' and $name eq 'type')
 				|| ($classNode->{astNodeName} eq 'QObject' and $name eq 'staticMetaObject')
 				|| ($classNode->{astNodeName} eq 'SlaveBase' and $name eq 'mIncomingMetaData')
 				|| ($classNode->{astNodeName} eq 'SlaveBase' and $name eq 'mOutgoingMetaData') ) 
@@ -733,6 +744,12 @@ my $fhn =1; # static
 	    print $fh "#include <qregexp.h>\n";
 		delete $includes{"qregexp.h"};
 	}
+
+    if (defined $includes{"qsslsocket.h"} && defined $includes{"qsslconfiguration.h"}) {
+        print $fh "#include <qsslconfiguration.h>\n";
+		delete $includes{"qsslconfiguration.h"};
+    }
+
 	if (	defined $includes{"qmime.h"} 
 			|| defined $includes{"qmetatype.h"} 
 			|| defined $includes{"qvariant.h"}
